  --name                  The name of the HTML file, without the .html extension
                          Can be set to - to write HTML to STDOUT (note
                          due to the nature of CLI argument parsing, this must 
                          be set using =, e.g. --name=-)

                          If either this flag or --output-html-file is set to - 
                          then the HTML will go to STDOUT.

                          Default: flamegraph

  --title                 Set the title to display in the flamegraph UI
                          Default: node [nodeFlags] script.js

  --open | -o             Automatically open after finishing
                          Default: false

  --prof-viz              Experimental. Node 8+ only. Create an additional 
                          flamegraph using log output when from the V8 --prof.
                          This will create an additional flamegraph named according 
                          to the --name flag, prefixed with v8-prof-. If --name 
                          is set to - then flamegraph HTML will be streamed
                          to STDOUT. 

  --prof-only             Experimental. Only create the prof-viz flamegraph 

  --phase                 Stage in initialization to begin aggregating
                          stacks. Phase 0 visualizes from the very start,
                          this includes bootstrapping stacks and loading 
                          the application module tree (these can dominate
                          the flamegraph). Phase 1 excludes core bootstrapping
                          stacks, except the end of the boostrapping process 
                          where the application module tree is loaded from 
                          the entry point. Phase 2 excludes all initialization, 
                          this renders the most pragmatic flamegraph for most 
                          use cases.
                          Default: 2

  --delay | -d            Delay before tracing begins, allows us to ignore
                          initialisation stacks (e.g. module loading).
                          Milliseconds
                          Default: 0

  --output-dir | -D       Specify artifact output directory.
                          Template variables {outputDir}, {pid}, {timestamp}, {cwd}
                          (current working directory) and {name} 
                          (based on the --name flag) are supported.

                          Default: '{pid}.flamegraph'

  --output-html | -F      Specify destination path for the flamegraph HTML file.
                          Template variables {outputDir}, {pid}, {timestamp}, {cwd}
                          (current working directory) and {name} 
                          (based on the --name flag) are supported. 
                          May also be set to - to send HTML file to STDOUT (note
                          due to the nature of CLI argument parsing, this must be 
                          set using =, e.g. --output-html=-).

                          If either this flag or --name is set to - then the HTML 
                          will go to STDOUT. 
                           
                          Default: '{outputDir}/{name}.html'

  --svg                   Generates an `flamegraph.svg` file in the artifact
                          output directory, in addition to the `flamegraph.html` file.

  --langs | -l            Coarser form of tiers, colour code by JS or C
                          Default: false

  --tiers | -t            Overrides langs, Colour code frames by type:
                          v8, regexp, nativeC, nativeJS, core, deps, app
                          Default: false

  --exclude | -x          Exclude tiers or langs, comma seperated list
                          Tiers: v8, regexp, nativeC, nativeJS, core, deps, app
                          Langs: js, c
                          Default: v8

  --include               Include tiers or langs. Overwrites exclude

  --theme                 Dark or Light theme
                          Default: light

  --trace-info            Show output from dtrace or perf tools
                          Default: false

  -q | --quiet            Only output flamegraph URI, and fatal errors.
                          Default: false

  -s | --silent           Complete silence, 0x will not output anything,
                          other than fatal errors.
                          Default: false

  --timestamp-profiles    Add timestamp to you profile folder's name

  --gen [flags] <file> |  Generate the flamegraph from a stacks.out file. 
  -g [flags] <file> |     Possible flags include --tiers and --langs and --name
                          Outputs HTML to STDOUT by default, unless --name is set.       
                          
  --json-stacks           Output a JSON file of stacks as stacks.<pid>.json


  --log-output            The logging output stream. Can be stdout or stderr
                          Default: stderr

  --collect-only          Do not process captured stacks into a flamegraph

  --visualize-only <folder> Build or rebuild visualization from original stacks, 
                            similar to --gen flag, except specify containing folder
                            instead of stacks file.  
